# error tags
je_auto_control_error = "Auto control error"
je_auto_control_critical_exit_error = "Auto control critical exit error"
# os tags
linux_import_error = "should be only loaded on linux"
osx_import_error = "should be only loaded on MacOS"
windows_import_error = "should be only loaded on windows"
macos_record_error = "macos can't use recorder"
# keyboard tags
keyboard_error = "Auto control keyboard error"
keyboard_press_key = "keyboard press key error"
keyboard_release_key = "keyboard release key error"
keyboard_type_key = "keyboard type key error"
keyboard_write = "keyboard write error"
keyboard_write_cant_find = "keyboard write error can't find key"
keyboard_hotkey = "keyboard hotkey error"
# mouse tags
mouse_error = "Auto control mouse error"
mouse_get_position = "mouse get position error"
mouse_set_position = "mouse set position error"
mouse_press_mouse = "mouse press mouse error"
mouse_release_mouse = "mouse release key error"
mouse_click_mouse = "mouse click mouse error"
mouse_scroll = "mouse scroll error"
# screen tags
screen_error = "Auto control screen error"
screen_get_size = "screen get size error"
screen_screenshot = "screen screenshot error"
# table tags
table_cant_find_key = "can't find key error"
# image tags
cant_find_image = "can't find image"
find_image_error_variable = "variable error"
# listener tags
listener_error = "Auto control listener error"
# record tags
record_queue_error = "can't get record queue it's none are you using stop record before record"
record_not_found_action_error = "record action not found"
# json action file tag
cant_execute_action_error = "can't execute action"
cant_find_json_error = "can't find json file"
cant_save_json_error = "can't save json file"
action_is_null_error = "json action is null"
# timeout tag
timeout_need_on_main_error = "should put timeout function on main"
